@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2023 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2024 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -76,6 +76,7 @@ static const char *os[][2] = {
   {"AppleTV", "iOS"},
   {"iTunes", "macOS"},
   {"OS X", "macOS"},
+  {"macOS", "macOS"},
   {"Darwin", "Darwin"},
 
   {"Debian", "Linux"},
@@ -379,7 +380,7 @@ parse_os (char *str, char *tkn, char *os_type, int idx) {
   if (strstr (tkn, "iPhone"))
     return xstrdup (parse_ios (tkn, 6));
   /* Mac OS X */
-  if ((strstr (tkn, "OS X")) != NULL) {
+  if (strstr (tkn, "OS X") || strstr (tkn, "macOS")) {
     tkn = parse_osx (tkn);
     return conf.real_os ? get_real_mac_osx (tkn) : xstrdup (tkn);
   }
