@@ -7,7 +7,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2023 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2024 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -1621,10 +1621,12 @@ is_static (const char *req) {
  * If the status code is within the ignore-array, 1 is returned. */
 static int
 ignore_status_code (int status) {
+  int i = 0;
+
   if (!status || conf.ignore_status_idx == 0)
     return 0;
 
-  for (int i = 0; i < conf.ignore_status_idx; i++)
+  for (i = 0; i < conf.ignore_status_idx; i++)
     if (status == conf.ignore_status[i])
       return 1;
 
@@ -1984,8 +1986,9 @@ read_line (GLog *glog, char *line, int *test, uint32_t *cnt, int dry_run) {
 static void *
 read_lines_thread (void *arg) {
   GJob *job = (GJob *) arg;
+  int i = 0;
 
-  for (int i = 0; i < job->p; i++) {
+  for (i = 0; i < job->p; i++) {
     /* ensure we don't process more than we should when testing for log format,
      * else free chunk and stop processing threads */
     if (!job->test || (job->test && job->cnt < conf.num_tests))
@@ -2048,7 +2051,9 @@ fgetline (FILE *fp) {
 void *
 process_lines_thread (void *arg) {
   GJob *job = (GJob *) arg;
-  for (int i = 0; i < job->p; i++) {
+  int i = 0;
+
+  for (i = 0; i < job->p; i++) {
     if (job->logitems[i] != NULL && !job->dry_run && job->logitems[i]->errstr == NULL) {
       process_log (job->logitems[i]);
       free_glog (job->logitems[i]);
@@ -2061,6 +2066,9 @@ process_lines_thread (void *arg) {
 static void
 init_jobs (GJob jobs[2][conf.jobs], GLog *glog, int dry_run, int test) {
   int b = 0, k = 0;
+#ifndef WITH_GETLINE
+  int i = 0;
+#endif
 
   for (b = 0; b < 2; b++) {
     for (k = 0; k < conf.jobs; k++) {
@@ -2073,7 +2081,7 @@ init_jobs (GJob jobs[2][conf.jobs], GLog *glog, int dry_run, int test) {
       jobs[b][k].logitems = xcalloc (conf.chunk_size, sizeof (GLogItem));
       jobs[b][k].lines = xcalloc (conf.chunk_size, sizeof (char *));
 #ifndef WITH_GETLINE
-      for (int i = 0; i < conf.chunk_size; i++)
+      for (i = 0; i < conf.chunk_size; i++)
         jobs[b][k].lines[i] = xcalloc (LINE_BUFFER, sizeof (char));
 #endif
     }
@@ -2119,11 +2127,14 @@ process_lines (GJob jobs[2][conf.jobs], uint32_t *cnt, int *test, int b) {
 static void
 free_jobs (GJob jobs[2][conf.jobs]) {
   int b = 0, k = 0;
+#ifndef WITH_GETLINE
+  int i = 0;
+#endif
 
   for (b = 0; b < 2; b++) {
     for (k = 0; k < conf.jobs; k++) {
 #ifndef WITH_GETLINE
-      for (int i = 0; i < conf.chunk_size; i++)
+      for (i = 0; i < conf.chunk_size; i++)
         free (jobs[b][k].lines[i]);
 #endif
       free (jobs[b][k].logitems);
@@ -2156,6 +2167,12 @@ read_lines (FILE *fp, GLog *glog, int dry_run) {
   while (1) {   /* b = 0 or 1 */
     read_lines_from_file (fp, glog, jobs, b, &s);
 
+    /* if nothing was read from the log, skip it for now */
+    if (!glog->bytes) {
+      test = 0;
+      break;
+    }
+
     if (conf.jobs == 1) {
       read_lines_thread (&jobs[b][1]);
     } else {
